==> hermes-2.3.4-61774926.tar.gz: hermes-2.3.4-61774926/lib/hermes/bo_client/tasks/find_nud_task.rb <==
# frozen_string_literal: true


=begin
nud = Hermes::Nud.first
so=Hermes::BoClient::FindNudTask.new({
                                                nud_id: nud.id,
                                            })
so.to_xml
ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)
=end

module Hermes
  module BoClient
    class FindNudTask < BaseTask
      
      def initialize(options = {})
        @xsd = 'RechercheDemande.xsd'
        super(options)
      end
      
      endpoint {'/ws/rest/als/demande/v1/rechercher'}
      
      task_name 'findnud'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::FindNudMap'
      
      params *%i[
      numUnique
      civilite
      nom
      prenom
      date_naissance
      commune_souhaitee
      ]
      
      def to_xml
        namespaces = {
            'xmlns:ns2' => 'http://v1.pma.ikos.webservice.immobilier.sopra/integration/demande/recherche'
        }
        builder = Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |b|
              b['ns2'].recherche_demande(namespaces) do
             
                 b.numUnique mapping.numUnique do
                   b.parent.namespace = nil
                 end
                 b.civilite mapping.civilite do
                   b.parent.namespace = nil
                 end
                 b.nom mapping.nom do
                   b.parent.namespace = nil
                 end
                 b.prenom mapping.prenom do
                   b.parent.namespace = nil
                 end
                 b.date_naissance mapping.date_naissance do
                   b.parent.namespace = nil
                 end
          end
        end
        builder.to_xml
      end
    end
  end
end

==> hermes-5.6.0.52.tar.gz: hermes-5.6.0.52/lib/hermes/bo_client/tasks/find_nud_task.rb <==
# frozen_string_literal: true


=begin
nud = Hermes::Nud.first
so=Hermes::BoClient::FindNudTask.new({
                                                nud_id: nud.id,
                                            })
so.to_xml
ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)
=end

module Hermes
  module BoClient
    class FindNudTask < BaseTask
      
      def initialize(options = {})
        @xsd = 'RechercheDemande.xsd'
        super(options)
      end
      
      endpoint {'/ws/rest/als/demande/v1/rechercher'}
      
      task_name 'findnud'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::FindNudMap'
      
      params *%i[
      numUnique
=begin
      civilite
      nom
      prenom
      date_naissance
      commune_souhaitee
=end
      ]
      
      def to_xml
        namespaces = {
            'xmlns:ns2' => 'http://v1.als.ikos.webservice.immobilier.sopra/integration/demande/recherche'
        }
        builder = Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |b|
              b['ns2'].recherche_demande(namespaces) do
             
                 b.numUnique mapping.numUnique do
                   b.parent.namespace = nil
                 end
=begin
                
                 b.civilite mapping.civilite do
                   b.parent.namespace = nil
                 end
                 b.nom mapping.nom do
                   b.parent.namespace = nil
                 end
                 b.prenom mapping.prenom do
                   b.parent.namespace = nil
                 end
                 b.date_naissance mapping.date_naissance do
                   b.parent.namespace = nil
                 end
=end
          end
        end
        builder.to_xml
      end
    end
  end
end
